@@ -7,13 +7,13 @@ use std::io::{self, IoSliceMut, Read};
 #[cfg(feature = "terminal-io")]
 use terminal_io::ReadTerminal;
 #[cfg(windows)]
-use unsafe_io::os::windows::{
+use io_extras::os::windows::{
     AsHandleOrSocket, AsRawHandleOrSocket, BorrowedHandleOrSocket, RawHandleOrSocket,
 };
 #[cfg(not(windows))]
 use {
     io_lifetimes::{AsFd, BorrowedFd},
-    unsafe_io::os::rsix::{AsRawFd, RawFd},
+    io_extras::os::rustix::{AsRawFd, RawFd},
 };
 
 /// Adapts an `Read` to implement `ReadLayered`.
